@@ -5,19 +5,7 @@
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef __FILTER_EXPRESSIONS_H__
@@ -37,7 +25,6 @@ extern "C" {
  */
 
 typedef struct filter_expression {
-	gpointer button;	/* Filter toolbar (GTK only) */
 	gchar	*label;
 	gchar	*expression;
 	gchar	*comment;
@@ -51,6 +38,7 @@ WS_DLL_PUBLIC void filter_expression_iterate_expressions(wmem_foreach_func func,
  *
  * @param label Label (button) text for the expression.
  * @param expr The display filter for the expression.
+ * @param comment A comment about the filter.
  * @param enabled Determines if the expression is shown in the UI.
  * @return A newly allocated and initialized struct filter_expression.
  */
