@@ -5,7 +5,7 @@
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- * SPDX-License-Identifier: GPL-2.0+
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef FILESYSTEM_H
@@ -29,7 +29,7 @@ extern "C" {
  * and save it for future use.  Returns NULL on success, and a
  * g_mallocated string containing an error on failure.
  */
-WS_DLL_PUBLIC char *init_progfile_dir(const char *arg0, int (*function_addr)(int, char **));
+WS_DLL_PUBLIC char *init_progfile_dir(const char *arg0);
 
 /*
  * Get the directory in which the program resides.
@@ -122,6 +122,12 @@ WS_DLL_PUBLIC gboolean has_global_profiles(void);
  */
 WS_DLL_PUBLIC char *get_profiles_dir(void);
 
+/*
+ * Get the directory used to store configuration files for a given profile.
+ * Caller must free the returned string.
+ */
+WS_DLL_PUBLIC char *get_profile_dir(const char *profilename, gboolean is_global);
+
 /*
  * Create the directory used to store configuration profile directories.
  */
@@ -155,6 +161,11 @@ WS_DLL_PUBLIC gboolean profile_exists(const gchar *profilename, gboolean global)
 WS_DLL_PUBLIC int create_persconffile_profile(const char *profilename,
 				       char **pf_dir_path_return);
 
+/*
+ * Returns the list of known profile config filesnames
+ */
+WS_DLL_PUBLIC const GHashTable * allowed_profile_filenames(void);
+
 /*
  * Delete the directory for the given configuration profile.
  * If we attempted to delete it, and failed, return -1 and
@@ -280,11 +291,22 @@ WS_DLL_PUBLIC int test_for_fifo(const char *);
  */
 WS_DLL_PUBLIC gboolean file_exists(const char *fname);
 
+/*
+ * Check if file is existing and has text entries which does not start
+ * with the comment character.
+ */
+WS_DLL_PUBLIC gboolean config_file_exists_with_entries(const char *fname, char comment_char);
+
 /*
  * Check if two filenames are identical (with absolute and relative paths).
  */
 WS_DLL_PUBLIC gboolean files_identical(const char *fname1, const char *fname2);
 
+/*
+ * Check if file has been recreated since it was opened.
+ */
+WS_DLL_PUBLIC gboolean file_needs_reopen(int fd, const char* filename);
+
 /*
  * Copy a file in binary mode, for those operating systems that care about
  * such things.  This should be OK for all files, even text files, as
